==> imageeditor-7.x-1.3.tar.gz: imageeditor/imageeditor_inline/imageeditor_inline.js <==
(function ($) {

Drupal.behaviors.imageeditor_inline = {};
Drupal.behaviors.imageeditor_inline.attach = function(context, settings) {
  Drupal.imageeditor_inline.initialize(context);
};

Drupal.imageeditor_inline = {
  initialize: function(context) {
    $('img', context).not('.imageeditor-inline-processed').each(function(index, Element) {
      if (this.naturalWidth == 0 || this.naturalHeight == 0) {
        setTimeout(function(){Drupal.imageeditor_inline.initialize(context);}, 1000);
      }
      else {
        $(this).addClass('imageeditor-inline-processed');
        if (this.naturalWidth >= Drupal.settings.imageeditor_inline.min_dimention || this.naturalHeight >= Drupal.settings.imageeditor_inline.min_dimention) {
          var origurl = $(this).attr('src');
          //regexp to detect and remove 'styles/style_name/scheme_name/'
          //Styles are using $scheme . '://styles/' . $style_name . '/' . $scheme . '/' . $path
          var fullurl = origurl.replace(new RegExp('styles/[0-9a-zA-z_]+/[0-9a-zA-z_]+/','g'), '');
          $(this).wrap("<div class='imageeditor-inline-wrapper'></div>");
          
          var options = {editors: Drupal.settings.imageeditor_inline.editors, uploaders: Drupal.settings.imageeditor_inline.uploaders, image: {url: fullurl}, data: {fullurl: fullurl, origurl: origurl}, $element: $(this), callback: Drupal.imageeditor_inline.save};
          Drupal.imageeditor.initialize(options);
          
          if (Drupal.settings.imageeditor_inline.icons_position == 1) {
            var $imageeditor_div = $(this).parents('div.imageeditor-inline-wrapper').css({'position': 'relative'}).find('div.imageeditor');
            $imageeditor_div.css({'position': 'absolute', 'bottom': '0px', 'margin-bottom': $(this).css('marginBottom')}).hide();
            $(this).parents('div.imageeditor-inline-wrapper').hover(
              function(event) {
                $imageeditor_div.show();
              },
              function(event) {
                $imageeditor_div.hide();
              }
            );
          }
          else {
            $(this).parents('div.imageeditor-inline-wrapper').find('.imageeditor').css({'height': '28px'});
          }
        }
      }
    });
  },
  save: function() {
    $.ajax({
      type: 'POST',
      url: Drupal.settings.imageeditor_inline.save_url,
      async: true, // explicitly need the user to wait while we load...
      data: {'image': Drupal.settings.imageeditor.save.image, 'fullurl': Drupal.settings.imageeditor.save.fullurl, 'origurl': Drupal.settings.imageeditor.save.origurl},
      success: function(data) {alert(data);},
      error: function(msg) {alert("Something went wrong : " + msg);}
    });
  }
};

})(jQuery);

==> imageeditor-7.x-1.4.tar.gz: imageeditor/imageeditor_inline/imageeditor_inline.js <==
(function ($) {

Drupal.behaviors.imageeditor_inline = {};
Drupal.behaviors.imageeditor_inline.attach = function(context, settings) {
  Drupal.imageeditor_inline.initialize(context);
};

Drupal.imageeditor_inline = {
  initialize: function(context) {
    $('img:not('+Drupal.settings.imageeditor_inline.ignore+')', context).not('.imageeditor-inline-processed').each(function(index, Element) {
      if (this.naturalWidth == 0 || this.naturalHeight == 0) {
        setTimeout(function(){Drupal.imageeditor_inline.initialize(context);}, 1000);
      }
      else {
        $(this).addClass('imageeditor-inline-processed');
        if (this.naturalWidth >= Drupal.settings.imageeditor_inline.min_dimention || this.naturalHeight >= Drupal.settings.imageeditor_inline.min_dimention) {
          var origurl = $(this).attr('src');
          //regexp to detect and remove 'styles/style_name/scheme_name/'
          //Styles are using $scheme . '://styles/' . $style_name . '/' . $scheme . '/' . $path
          var fullurl = origurl.replace(new RegExp('styles/[0-9a-zA-z_]+/[0-9a-zA-z_]+/','g'), '');
          $(this).wrap("<div class='imageeditor-inline-wrapper'></div>");
          
          var options = {editors: Drupal.settings.imageeditor_inline.editors, uploaders: Drupal.settings.imageeditor_inline.uploaders, image: {url: fullurl}, data: {fullurl: fullurl, origurl: origurl}, $element: $(this), callback: Drupal.imageeditor_inline.save};
          Drupal.imageeditor.initialize(options);
          
          if (Drupal.settings.imageeditor_inline.icons_position == 1) {
            var $imageeditor_inline_wrapper_div = $(this).parents('div.imageeditor-inline-wrapper');
            var $imageeditor_div = $imageeditor_inline_wrapper_div.css({'position': 'relative'}).find('div.imageeditor');
            $imageeditor_div.css({'position': 'absolute', 'bottom': '0px'}).hide();
            $imageeditor_inline_wrapper_div.hover(
              function(event) {
                $imageeditor_div.fadeIn();
              },
              function(event) {
                $imageeditor_div.fadeOut();
              }
            );
          }
        }
      }
    });
  },
  save: function() {
    $.ajax({
      type: 'POST',
      url: Drupal.settings.imageeditor_inline.save_url,
      async: true,
      data: {'image': Drupal.settings.imageeditor.save.image, 'fullurl': Drupal.settings.imageeditor.save.fullurl, 'origurl': Drupal.settings.imageeditor.save.origurl},
      success: function(data) {alert(data);},
      error: function(msg) {alert("Something went wrong : " + msg);}
    });
  }
};

})(jQuery);
